@@ -178,7 +178,7 @@ void ExportMailJob::slotWriteNextArchiveResource()
                         QTimer::singleShot(0, this, &ExportMailJob::slotMailsJobTerminated);
                     }
                 } else if (identifier.contains(QLatin1String("akonadi_mbox_resource_"))) {
-                    backupResourceFile(agent, Utils::addressbookPath());
+                    backupResourceFile(agent, Utils::mailsPath());
                     QTimer::singleShot(0, this, &ExportMailJob::slotMailsJobTerminated);
                 } else {
                     QTimer::singleShot(0, this, &ExportMailJob::slotMailsJobTerminated);
@@ -583,9 +583,8 @@ void ExportMailJob::backupConfig()
         }
 
         //Automatic Add Contacts
-        KIdentityManagement::IdentityManager *im = KIdentityManagement::IdentityManager::self();
-        KIdentityManagement::IdentityManager::ConstIterator end = im->end();
-        for (KIdentityManagement::IdentityManager::ConstIterator it = im->begin(); it != end; ++it) {
+        KIdentityManagement::IdentityManager::ConstIterator end = mIdentityManager->end();
+        for (KIdentityManagement::IdentityManager::ConstIterator it = mIdentityManager->begin(); it != end; ++it) {
             const uint identity = (*it).uoid();
             const QString groupId = QStringLiteral("Automatic Add Contacts %1").arg(identity);
             if (kmailConfig->hasGroup(groupId)) {
